﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace Schach
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        Schachfigur[] figuren = new Schachfigur[4];
        TextBlock[,] textblöcke = new TextBlock[8, 8];

        public MainWindow()
        {
            InitializeComponent();

            figuren[0] = new Turm(new Punkt(2, 3), false);
            figuren[1] = new Turm(new Punkt(4, 1), true);
            figuren[2] = new Läufer(new Punkt(2, 4), false);
            figuren[3] = new Läufer(new Punkt(1, 6), true);

            for (int i = 0; i < 8; i++)
            {
                for (int j = 0; j < 8; j++)
                {
                    TextBlock b = new TextBlock();
                    b.Width = 30;
                    b.Height = 30;
                    b.Text = "*";
                    b.FontSize = 25;
                    b.Background = ((i + j) % 2 != 0) ? Brushes.White : Brushes.LightGray;
                    spielfeld.Children.Add(b);
                    textblöcke[i, j] = b;
                    Canvas.SetLeft(b, 30 * i);
                    Canvas.SetBottom(b, 30 * j);
                    b.MouseDown += MausGedrückt;
                    b.MouseUp += MausLosgelassen;
                    b.MouseEnter += MausHinein;
                    b.MouseLeave += MausHeraus;
                }
            }
            Zeichne();
        }

        Punkt sucheTextBlock(TextBlock s)
        {
            Punkt p = new Punkt(-1, -1);
            for (int i = 0; i < 8; i++)
            {
                for (int j = 0; j < 8; j++)
                {
                    if (textblöcke[i, j] == s)
                    {
                        p = new Punkt(i, j);
                    }
                }
            }
            return p;
        }

        Schachfigur sucheFigur(Punkt p)
        {
            for (int i = 0; i < figuren.Length; i++)
            {
                if (figuren[i].Position.X == p.X && figuren[i].Position.Y == p.Y)
                {
                    return figuren[i];
                }
            }
            return null;
        }

        void MausGedrückt(object sender, MouseEventArgs e)
        {
            TextBlock s = (TextBlock)sender;
            Punkt p = sucheTextBlock(s);

            bewegteFigur = sucheFigur(p);
        }

        void MausLosgelassen(object sender, MouseEventArgs e)
        {
            TextBlock s = (TextBlock)sender;
            Punkt p = sucheTextBlock(s);

            if (bewegteFigur != null)
            {
                if (bewegteFigur.BewegeNach(p))
                {
                    Zeichne();
                }
                else
                {
                    MessageBox.Show("Nicht erlaubt!");
                }
            }
        }

        void MausHinein(object sender, MouseEventArgs e)
        {
            TextBlock s = (TextBlock)sender;
            Punkt p = sucheTextBlock(s);

            Schachfigur tippsFigur = sucheFigur(p);

            if (tippsFigur != null)
            {
                for (int i = 0; i < 8; i++)
                {
                    for (int j = 0; j < 8; j++)
                    {
                        if (tippsFigur.IstZugErlaubt(new Punkt(i, j)))
                        {
                            textblöcke[i, j].Background = Brushes.LightGreen;
                        }
                    }
                }
            }

        }

        void MausHeraus(object sender, MouseEventArgs e)
        {
            for (int i = 0; i < 8; i++)
            {
                for (int j = 0; j < 8; j++)
                {
                    textblöcke[i, j].Background = ((i + j) % 2 != 0) ? Brushes.White : Brushes.LightGray;
                }
            }
        }

        Schachfigur bewegteFigur;

        void Zeichne()
        {

            for (int i = 0; i < 8; i++)
            {
                for (int j = 0; j < 8; j++)
                {
                    textblöcke[i, j].Text = "";
                    for (int k = 0; k < figuren.Length; k++)
                    {
                        if (figuren[k].Position.Vergleiche(new Punkt(i, j)))
                        {
                            textblöcke[i, j].Text = figuren[k].Form.ToString();
                            break;
                        }
                    }
                }
            }
        }
    }
}
