﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Schach
{
    class Punkt
    {
        public Punkt(int x, int y)
        {
            this.x = x;
            this.y = y;
        }

        int x; // Spalte 0...7
        public int X
        { get { return x; } }

        int y; // Zeile 0...7, unten Zeile 0
        public int Y
        { get { return y; } }

        public bool Vergleiche(Punkt punkt)
        {
            return X == punkt.X && Y == punkt.Y;
        }
    }

    abstract class Schachfigur
    {
        protected Punkt p; 
        public Punkt Position
        {
            get { return p; }
        }
        protected bool istWeiß;
        protected char form;
        public char Form
        {
            get { return form;  }
        }

        // Annahme: xZiel und yZiel sind zwischen 0 und 7
        // Annahme: Zielpunkt != Startpunkt
        // Annahme: Niemand steht im Weg.
        // Rückgabe: Ist Zug erlaubt?
        public bool BewegeNach(Punkt ziel)
        {
            if (IstZugErlaubt(ziel))
            {
                p = ziel;
                return true;
            }
            return false;
        }

        public abstract bool IstZugErlaubt(Punkt ziel);

        public Schachfigur(Punkt p, bool istWeiß, char form)
        {
            this.p = p;
            this.istWeiß = istWeiß;
            this.form = form;
        }
    }

    class Turm : Schachfigur
    {
        public Turm(Punkt p, bool istWeiß)
            : base(p, istWeiß, istWeiß ? '♖' : '♜')
        {
        }

        public override bool IstZugErlaubt(Punkt ziel)
        {
            return ziel.X == p.X || ziel.Y == p.Y;
        }
    }

    class Läufer : Schachfigur
    {
        public Läufer(Punkt p, bool istWeiß)
            : base(p, istWeiß, istWeiß ? '♗' : '♝')
        {
        }

        public override bool IstZugErlaubt(Punkt ziel)
        {
            return ziel.Y == p.Y + p.X - ziel.X || ziel.Y == p.Y - p.X + ziel.X;
        }
    }
}
